package org.psesquared.server.episode.actions.api.data.access;

import java.util.Optional;
import org.psesquared.server.model.Episode;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.stereotype.Repository;

/**
 * A DAO interface responsible for transactions involving Episodes.
 */
@Repository
public interface EpisodeDao extends JpaRepository<Episode, Long> {

  /**
   * Find an episode by its URL.
   *
   * @param url The URL of the episode
   * @return The matching episode / NULL, if there was no match.
   */
  Optional<Episode> findByUrl(String url);

  /**
   * Returns true if there is an episode that matches a given URL.
   *
   * @param url The URL of the episode
   * @return A boolean value signifying whether the episode exists
   */
  boolean existsByUrl(String url);

  /**
   * Returns true if there is an episode that matches a given GUID.
   *
   * @param guid The GUID of the episode
   * @return A boolean value signifying whether the episode exists
   */
  boolean existsByGuid(String guid);

  /**
   * Find an episode by its GUID.
   *
   * @param guid The GUID of the episode
   * @return The matching episode / NULL, if there was no match.
   */
  Optional<Episode> findByGuid(String guid);

}
