package org.psesquared.server.subscriptions.api.data.access;

import java.util.Optional;
import org.psesquared.server.model.Subscription;
import org.springframework.data.jpa.repository.EntityGraph;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.stereotype.Repository;

/**
 * A DAO interface responsible for transactions involving Subscriptions.
 */
@Repository
public interface SubscriptionDao extends JpaRepository<Subscription, Long> {

  /**
   * Find a subscription by its URL.
   *
   * @param url The URL of the subscription
   * @return The found subscription (could be NULL, if there was no match)
   */
  @EntityGraph(value = "graph.Subscription.episodes")
  Optional<Subscription> findByUrl(String url);

  /**
   * Returns true if the database already has a Subscription that has the given
   * URL.
   *
   * @param url The URL of the Subscription that could already exist in the
   *            database
   * @return A boolean value signifying the existence of the Subscription
   */
  boolean existsByUrl(String url);

}
