package org.psesquared.server.authentication.api.data.access;

import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.psesquared.server.model.Role;
import org.psesquared.server.model.User;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.jdbc.AutoConfigureTestDatabase;
import org.springframework.boot.test.autoconfigure.orm.jpa.DataJpaTest;

import java.time.LocalDateTime;
import java.time.ZoneOffset;

import static org.junit.jupiter.api.Assertions.assertTrue;

@DataJpaTest
@AutoConfigureTestDatabase(replace = AutoConfigureTestDatabase.Replace.NONE)
public class AuthenticationDaoTest {

    @Autowired
    private AuthenticationDao authenticationDao;

    @BeforeEach
    public void init() {
        var user = User.builder()
                .username("username")
                .email("email")
                .password("password")
                .enabled(false)
                .createdAt(LocalDateTime.now().toEpochSecond(ZoneOffset.UTC))
                .role(Role.USER)
                .build();
        authenticationDao.save(user);
    }

    @Test
    public void updateUser() {
        var user = authenticationDao.findByUsername("username")
                .orElseThrow();
        user.setEnabled(true);
    }

    @AfterEach
    public void assertUpdated() {
        var foundUser = authenticationDao.findByUsername("username")
                .orElseThrow();
        assertTrue(foundUser.isEnabled());
    }

}
