package org.psesquared.server.subscriptions.api.data.access;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;

import java.io.File;
import java.util.List;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.psesquared.server.BaseTest;
import org.psesquared.server.model.Subscription;
import org.psesquared.server.model.SubscriptionAction;
import org.psesquared.server.model.User;

public class SubscriptionActionDaoTests extends BaseTest {

    @Test
    public void existsByUserAndSubscriptionTest() {
        String username = "testUser0";
        String subscriptionUrl = new File("testfeeds/testPodcast0.xml").toURI().toString();
        User user = authenticationDao.findByUsername(username).orElseThrow();
        Subscription subscription = subscriptionDao.findByUrl(subscriptionUrl).orElseThrow();
        boolean exists = subscriptionActionDao.existsByUserAndSubscription(user, subscription);
        assertTrue(exists);
    }

    @Test
    public void findByUserAndSubscriptionTest() {
        String username = "testUser0";
        String subscriptionUrl = new File("testfeeds/testPodcast0.xml").toURI().toString();
        User user = authenticationDao.findByUsername(username).orElseThrow();
        Subscription subscription = subscriptionDao.findByUrl(subscriptionUrl).orElseThrow();
        SubscriptionAction subscriptionAction = subscriptionActionDao.findByUserAndSubscription(user, subscription)
                .orElseThrow();
        assertEquals(subscriptionAction.getSubscription().getUrl(), subscriptionUrl);
    }

    @Test
    public void findByUserUsernameAndTimestampGreaterThanEqualTest() {
        String username = "testUser0";
        // Jede SubscriptionAction eines Nutzers hat einen Timestamp von zusätzlichen
        // 1000000 zur Zeit 0
        int factor = 1;
        int timeDifference = 1000000;
        long since = factor * timeDifference;
        List<SubscriptionAction> subscriptionActions = subscriptionActionDao
                .findByUserUsernameAndTimestampGreaterThanEqual(username, since);
        assertEquals(numberOfSubscriptionsPerUser - factor, subscriptionActions.size());
    }

    @Test
    public void findByUserUsernameAndAddedTrueTest() {
        String username = "testUser0";
        List<SubscriptionAction> subscriptionActions = subscriptionActionDao.findByUserUsernameAndAddedTrue(username);
        assertEquals(subscriptionActions.size(), numberOfSubscriptionsPerUser);
    }

    @Test
    public void findByUserUsernameAndAddedTrueAndTimestampGreaterThanEqualTest() {
        String username = "testUser0";
        // Jede SubscriptionAction eines Nutzers hat einen Timestamp von zusätzlichen
        // 1000000 zur Zeit 0
        // int puffer = 1000;
        int factor = 1;
        int timeDifference = 1000000;
        long since = factor * timeDifference;
        List<SubscriptionAction> subscriptionActions = subscriptionActionDao
                .findByUserUsernameAndTimestampGreaterThanEqual(username, since);
        assertEquals(numberOfSubscriptionsPerUser - factor, subscriptionActions.size());
        // Eine EpisodeAction der gefundenen EpisodeActions auf added=false setzen
        subscriptionActions.get(0).setAdded(false);
        subscriptionActionDao.save(subscriptionActions.get(0));
        List<SubscriptionAction> subscriptionActions2 = subscriptionActionDao
                .findByUserUsernameAndAddedTrueAndTimestampGreaterThanEqual(username, since);
        assertEquals(numberOfSubscriptionsPerUser - factor - 1, subscriptionActions2.size());
    }

    @Test
    public void deleteUserTest() {
        String username = "testUser0";
        User user = authenticationDao.findByUsername(username).orElseThrow();
        Assertions.assertEquals(numberOfSubscriptionsPerUser,
                subscriptionActionDao.findByUserUsernameAndAddedTrue(username).size());
        authenticationDao.delete(user);
        Assertions.assertEquals(0, subscriptionActionDao.findByUserUsernameAndAddedTrue(username).size());
    }

}
